@@ -1,7 +1,7 @@
 \unset ECHO
 \i test/setup.sql
 
-SELECT plan(132);
+SELECT plan(134);
 --SELECT * from no_plan();
 
 -- These will be rolled back. :-)
@@ -45,6 +45,27 @@ CREATE TABLE public.fk4 (
     id INT REFERENCES pk3(id)
 );
 
+CREATE TEMP TABLE temp_pk(
+    id    INT NOT NULL PRIMARY KEY,
+    name  TEXT DEFAULT ''
+);
+
+CREATE TEMP TABLE temp_fk (
+    id    INT NOT NULL PRIMARY KEY,
+    pk_id INT NOT NULL REFERENCES temp_pk(id)
+);
+
+-- Create a funcion to return the temp scheme name.
+DO $F$
+BEGIN
+    IF pg_version_num() >= 95000 THEN
+        EXECUTE 'CREATE FUNCTION tmpns() RETURNS NAME AS $$ SELECT pg_my_temp_schema()::regnamespace::name $$ LANGUAGE SQL;';
+    ELSE
+        EXECUTE 'CREATE FUNCTION tmpns() RETURNS NAME AS $$ SELECT nspname FROM pg_namespace WHERE oid = pg_my_temp_schema() $$ LANGUAGE SQL;';
+    END IF;
+END;
+$F$;
+
 RESET client_min_messages;
 
 /****************************************************************************/
@@ -330,6 +351,14 @@ SELECT * FROM check_test(
     'WHATEVER'
 );
 
+-- Make sure it works with the temp schema.
+SELECT * FROM check_test(
+    fk_ok( tmpns(), 'temp_fk', ARRAY['pk_id'], tmpns(), 'temp_pk', ARRAY['id'], 'WHATEVER' ),
+    true,
+    'pg_my_temp_schema()',
+    'WHATEVER'
+);
+
 SELECT * FROM check_test(
     fk_ok( 'public', 'fk2', ARRAY['pk2_num', 'pk2_dot'], 'public', 'pk2', ARRAY['num', 'dot'] ),
     true,
